heif_context_get_max_decoding_threads

Function heif_context_get_max_decoding_threads 

pub unsafe extern "C" fn heif_context_get_max_decoding_threads(
    ctx: *const heif_context,
) -> c_int
Returns the current maximum number of background threads used for parallel tile decoding. This reflects either the library default or the value last passed to heif_context_set_max_decoding_threads(). If ‘ctx’ is NULL, the library default is returned.