heif_context_set_write_mini_format

Function heif_context_set_write_mini_format 

pub unsafe extern "C" fn heif_context_set_write_mini_format(
    arg1: *mut heif_context,
    enable: c_int,
)
Enable writing in the compact ‘mini’ box format (ISO/IEC 23008-12 DAmd2). When enabled, the output file will use a single ‘mini’ box instead of the standard meta+mdat box structure, if the file content is compatible with the mini format. If the content cannot be represented as a mini box, the standard format is used as fallback. Note: the mini box format is defined by a draft amendment to ISO/IEC 23008-12 and may have reduced interoperability with other readers. Default: disabled.