heif_content_light_level

Struct heif_content_light_level 

#[repr(C)]
pub struct heif_content_light_level { pub max_content_light_level: u16, pub max_pic_average_light_level: u16, }
Semantics follow the H.265 ‘Content light level information’ SEI message (ITU-T H.265 Annex D.3.35). Identifies upper bounds for the nominal target brightness light level of the pictures. The bounds are defined against samples in a 4:4:4 RGB representation in the linear light domain, in units of candelas per square metre (cd/m^2 = nits). A field value of 0 means “no upper bound indicated” (i.e. undefined).

Fields

max_content_light_level: u16

Upper bound on the maximum light level among all individual linear-light 4:4:4 RGB samples across the sequence, in cd/m^2 (= field). Also called MaxCLL.

max_pic_average_light_level: u16

Upper bound on the maximum per-picture average light level among the linear-light 4:4:4 RGB samples (averaged over any individual picture), in cd/m^2 (= field). Also called MaxFALL (or MaxPALL). For letterboxed content the average is expected to be taken only over the visually relevant region (H.265 D.3.35 NOTE 3).