pub unsafe extern "C" fn heif_image_set_bayer_pattern(
arg1: *mut heif_image,
bayer_component_id: u32,
pattern_width: u16,
pattern_height: u16,
patternPixels: *const heif_bayer_pattern_pixel,
) -> heif_errorExpand description
Set a Bayer / filter array pattern on an image. The pattern is a 2D array of component indices with dimensions pattern_width x pattern_height. The number of entries in patternPixels must be pattern_width * pattern_height. The component_index values are indices into the cmpd component definition table. On the encoder path, these indices are generated by heif_image_add_component() and the encoder adds reference components to cmpd for pattern entries that don’t have image planes. On the decoder path, they come directly from the cpat box.